RandomPersonData class

Constructors

RandomPersonData({Gender? gender, Name? name, Location? location, String? email, UserLogin? login, Dob? dob, UserRegistered? registered, String? phone, String? cell, UserLogin? id, Picture? picture, UserNationality? nat})
RandomPersonData.fromJson(Map<String, dynamic> json)
factory

Properties

cell String?
getter/setter pair
dob Dob?
getter/setter pair
email String?
getter/setter pair
gender Gender?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id UserLogin?
getter/setter pair
location Location?
getter/setter pair
login UserLogin?
getter/setter pair
name Name?
getter/setter pair
nat UserNationality?
getter/setter pair
phone String?
getter/setter pair
picture Picture?
getter/setter pair
registered UserRegistered?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited