Location class
Constructors
- Location({UserStreet? street, String? city, String? state, String? country, String? postcode, UserCoordinates? coordinates, UserTimezone? timezone})
-
Location.fromJson(Map<
String, dynamic> json) -
factory
Properties
- city ↔ String?
-
getter/setter pair
- coordinates ↔ UserCoordinates?
-
getter/setter pair
- country ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- postcode ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
getter/setter pair
- street ↔ UserStreet?
-
getter/setter pair
- timezone ↔ UserTimezone?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited